@@ -1,6 +1,6 @@
 from zope.component import queryUtility
 from zope.event import notify
-from zope.interface import implements
+from zope.interface import implementer
 from z3c.form import button, form
 from z3c.form.interfaces import IEditForm, DISPLAY_MODE
 
@@ -9,7 +9,7 @@ from plone.memoize.instance import memoize
 from plone.autoform.form import AutoExtensibleForm
 from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
 
-from plone.schemaeditor import SchemaEditorMessageFactory as _
+from plone.schemaeditor import _
 from plone.schemaeditor.interfaces import IFieldFactory
 from plone.schemaeditor.utils import SchemaModifiedEvent
 
@@ -21,8 +21,8 @@ except ImportError:
 
 
 
+@implementer(IEditForm)
 class SchemaListing(AutoExtensibleForm, form.Form):
-    implements(IEditForm)
 
     ignoreContext = True
     ignoreRequest = True
